Learn R Programming

modeltime.resample (version 0.3.0)

unnest_modeltime_resamples: Unnests the Results of Modeltime Fit Resamples

Description

An internal function used by modeltime_resample_accuracy().

Usage

unnest_modeltime_resamples(object)

Value

Tibble with columns for '.row_id', '.resample_id', '.model_id', '.model_desc', '.pred', '.row', and actual value name from the data set

Arguments

object

A Modeltime Table that has a column '.resample_results'

Details

The following data columns are unnested and prepared for evaluation:

  • .row_id - A unique identifier to compare observations.

  • .resample_id - A unique identifier given to the resample iteration.

  • .model_id and .model_desc - Modeltime Model ID and Description

  • .pred - The Resample Prediction Value

  • .row - The actual row value from the original dataset

  • Actual Value Column - The name changes to target variable name in dataset

Examples

Run this code

# The .resample_results column is deeply nested
m750_training_resamples_fitted

# Unnest and prepare the resample predictions for evaluation
unnest_modeltime_resamples(m750_training_resamples_fitted)

Run the code above in your browser using DataLab